@@ -59,7 +59,12 @@ def pasteText(widget, TextArea, LangPickerButton, LangSelectorObj, AmpPickerButt
  data = clip.wait_for_contents('UTF8_STRING')
  text = data.get_text()
  buffer = TextArea.get_buffer()
- buffer.set_text(buffer.get_text(buffer.get_start_iter(), buffer.get_end_iter(), False) + text)
+
+ selectedText = buffer.get_selection_bounds()
+ if selectedText!=(): # If there is selected text, delete the selected text
+	buffer.delete_selection(True,True)
+ buffer.set_text(buffer.get_text(buffer.get_start_iter(), buffer.get_iter_at_mark(buffer.get_insert()), False) + text + buffer.get_text(buffer.get_iter_at_mark(buffer.get_insert()), buffer.get_end_iter(), False))
+ 
  TextArea.set_buffer(buffer)
 
  # The method that clears the TextView control content.
@@ -234,8 +239,9 @@ def main():
 	settingsDOM = xml.dom.minidom.parseString(getDefaultSettingsXML())
  
 # Create a new hildon stackable window
- window = hildon.StackableWindow()
- scrolledwindow = gtk.ScrolledWindow(hadjustment=None, vadjustment=None)
+ window = hildon.StackableWindow() 
+ pannableArea = hildon.PannableArea()
+ pannableArea.set_property("mov-mode", hildon.MOVEMENT_MODE_BOTH) 
  
  main_window = window
  app_name = _("eSpeakGUI_ApplicationName")
@@ -341,10 +347,10 @@ def main():
  textview.set_wrap_mode(gtk.WRAP_CHAR)
  buffer = textview.get_buffer() 
  buffer.connect("changed",text_changed)
- scrolledwindow.add(textview) 
+ pannableArea.add_with_viewport(textview)
  
  hbox2 = gtk.HBox(False, 0)  
- hbox2.pack_start(scrolledwindow, True, True, 0)
+ hbox2.pack_start(pannableArea, True, True, 0)
 
 # Define vertical box for action buttons 
  vbox2 = gtk.VBox(True ,0)
